simple-messaging.socket


start-socket-server!clj

(start-socket-server! port
                      handler
                      on-start
                      on-exit
                      {:keys [timeout accept-timeout num-threads]
                       :or {timeout 60000 accept-timeout 5000 num-threads 10}})

The handler that you pass reify the simple-messaging.common.ConnectionHandler protocol

timeout is the time to wait for bytes from a client accept-timeout is the time to wait for a socket connection

See the streamful.server.server-test for more.

The `handler` that you pass reify the
 `simple-messaging.common.ConnectionHandler protocol`

 `timeout` is the time to wait for bytes from a client
 `accept-timeout` is the time to wait for a socket connection

See the `streamful.server.server-test` for more.
raw docstring

cljdoc builds & hosts documentation for Clojure/Script libraries