simple-messaging.temp


cleanup-all-tempdirs!clj

(cleanup-all-tempdirs!)

Remove and forget all temporary directory of all sessions.

Remove and forget all temporary directory of all sessions.
raw docstring

cleanup-old-temp-files!clj

(cleanup-old-temp-files! older-than)
(cleanup-old-temp-files! now older-than)

cleanup-previous-sessions!clj

(cleanup-previous-sessions!)

file-structureclj

(file-structure file)

get-tempfilesclj

(get-tempfiles)

Retrieve list of all temp files

Retrieve list of all temp files
raw docstring

new-session!clj

(new-session!)

reset-temp-dir-root!clj

(reset-temp-dir-root!)

session-tempdir!clj

(session-tempdir!)

Get the temporary directory of the current session.

Get the temporary directory of the current session.
raw docstring

set-temp-dir-root!clj

(set-temp-dir-root! new-temp-dir)

temp-file!clj

(temp-file! extension)

Get the recommended path and route for a temporary file of the given extension, implicitly creating a temporary directory for this session, if needed.

Get the recommended `path` and `route` for a temporary file
of the given extension, implicitly creating a temporary directory
for this session, if needed.
raw docstring

cljdoc builds & hosts documentation for Clojure/Script libraries