(buf->byte-stream! bytes-to-read msg)(buf->temp-file-stream! file-channel-chunk-size bytes-to-read msg)(report-error e)(start-netty-server! port
handler
on-start
on-exit
{:keys [timeout accept-timeout file-buffer-bytes
file-channel-chunk-size]
:or {timeout 60000
accept-timeout 5000
file-buffer-bytes 1024
file-channel-chunk-size 1024}})The handler that you pass reify the
simple-messaging.common.ConnectionHandler protocol
timeout is the time to wait for bytes from a client
accept-timeout is the time to wait for a socket connection
file-buffer-bytes is the size an incoming message must be to stream
to a temp file
file-channel-chunk-size is the size of a single chunk to read into memory
before writing to the aforementioned file buffer
See the streamful.server.server-test for more.
The `handler` that you pass reify the
`simple-messaging.common.ConnectionHandler protocol`
`timeout` is the time to wait for bytes from a client
`accept-timeout` is the time to wait for a socket connection
`file-buffer-bytes` is the size an incoming message must be to stream
to a temp file
`file-channel-chunk-size` is the size of a single chunk to read into memory
before writing to the aforementioned file buffer
See the `streamful.server.server-test` for more.(stream->buf! num-bytes in)(stream->temp->buf! num-bytes in)cljdoc builds & hosts documentation for Clojure/Script libraries
| Ctrl+k | Jump to recent docs |
| ← | Move to previous article |
| → | Move to next article |
| Ctrl+/ | Jump to the search field |