(cleanup-all-tempdirs!)Remove and forget all temporary directory of all sessions.
Remove and forget all temporary directory of all sessions.
(cleanup-old-temp-files! older-than)(cleanup-old-temp-files! now older-than)(cleanup-previous-sessions!)(file-structure file)(get-tempfiles)Retrieve list of all temp files
Retrieve list of all temp files
(new-session!)(reset-temp-dir-root!)(session-tempdir!)Get the temporary directory of the current session.
Get the temporary directory of the current session.
(set-temp-dir-root! new-temp-dir)(temp-file! extension)Get the recommended path and route for a temporary file
of the given extension, implicitly creating a temporary directory
for this session, if needed.
Get the recommended `path` and `route` for a temporary file of the given extension, implicitly creating a temporary directory for this session, if needed.
cljdoc builds & hosts documentation for Clojure/Script libraries
| Ctrl+k | Jump to recent docs |
| ← | Move to previous article |
| → | Move to next article |
| Ctrl+/ | Jump to the search field |